# nodehandler-utils

nodehandler utils

# API Reference

**Example** *(Quick start)*  
```javascript
 const { NodeHandlerUtils } = require('nodehandler-utils');
 const { FlowManager } = require('axway-flow');
 const uri = FlowManager.formatNodeHandlerUri('service-connector', 'thing');
 const swagger = require('./thing.json');
 const schemas =  NodeHandlerUtils.exportSchemas(swagger, 'thing');
 const spec =  NodeHandlerUtils.swaggerToNodeHandlerSpec(swagger, 'thing', uri, 'thing-icon');
 const icon = NodeHandlerUtils.loadIcon('icon.png');
```
<a name="module_nodehandler-utils..NodeHandlerUtils"></a>

### nodehandler-utils~NodeHandlerUtils
Node handler utils

**Kind**: inner class of [<code>nodehandler-utils</code>](#module_nodehandler-utils)  
**Access**: public  

* [~NodeHandlerUtils](#module_nodehandler-utils..NodeHandlerUtils)
    * [.getSwaggerMethodAsProperties(swagger, name, verb, path)](#module_nodehandler-utils..NodeHandlerUtils.getSwaggerMethodAsProperties) ⇒ <code>object</code>
    * [.swaggerToNodeHandlerSpec(swagger, scope, uri, [icon])](#module_nodehandler-utils..NodeHandlerUtils.swaggerToNodeHandlerSpec) ⇒ <code>object</code>
    * [.exportSchemas(swagger, scope)](#module_nodehandler-utils..NodeHandlerUtils.exportSchemas) ⇒ <code>array</code>
    * [.loadIcon(file)](#module_nodehandler-utils..NodeHandlerUtils.loadIcon) ⇒ <code>Promise.&lt;string&gt;</code>
    * [.formatNodeHandlerUri(module, type)](#module_nodehandler-utils..NodeHandlerUtils.formatNodeHandlerUri) ⇒ <code>string</code>

<a name="module_nodehandler-utils..NodeHandlerUtils.getSwaggerMethodAsProperties"></a>

#### NodeHandlerUtils.getSwaggerMethodAsProperties(swagger, name, verb, path) ⇒ <code>object</code>
Converts the swagger parameters to json-schema properties.

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>object</code> - schema property  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>object</code> | swagger doc |
| name | <code>string</code> | The name of the node handler |
| verb | <code>object</code> | the method verb |
| path | <code>object</code> | the method path under swagger.paths |

<a name="module_nodehandler-utils..NodeHandlerUtils.swaggerToNodeHandlerSpec"></a>

#### NodeHandlerUtils.swaggerToNodeHandlerSpec(swagger, scope, uri, [icon]) ⇒ <code>object</code>
Converts a swagger definition to a flow-node spec.  The `uri` uniquely identifies
the flow-node, e.g. nodehandler://service-connector/foo (see `FlowManager.formatNodeHandlerUri`).

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>object</code> - flow-node spec  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>object</code> | The swagger document to convert |
| scope | <code>string</code> | The flow-node scope used in schema references |
| uri | <code>string</code> | The unique uri of the flow-node |
| [icon] | <code>string</code> | The flow-node's icon (defaults to `glyphicon-link`). |

<a name="module_nodehandler-utils..NodeHandlerUtils.exportSchemas"></a>

#### NodeHandlerUtils.exportSchemas(swagger, scope) ⇒ <code>array</code>
Exports schema from a swagger document.  Before returning, all of the references are
rewritten to an axway-schema type reference, and identifiers are applied to each
schema.

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>array</code> - An array of schemas.  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>object</code> | The swagger document to use to register schemas |
| scope | <code>string</code> | The flow-node scope used in schema references |

<a name="module_nodehandler-utils..NodeHandlerUtils.loadIcon"></a>

#### NodeHandlerUtils.loadIcon(file) ⇒ <code>Promise.&lt;string&gt;</code>
Loads an icon file and returns it as a data URI.  Supports bmp, jpeg, jpg, png, gif,
tiff, and svg.

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>Promise.&lt;string&gt;</code> - The icon data URI.  

| Param | Type | Description |
| --- | --- | --- |
| file | <code>string</code> | The icon file to load. |

<a name="module_nodehandler-utils..NodeHandlerUtils.formatNodeHandlerUri"></a>

#### NodeHandlerUtils.formatNodeHandlerUri(module, type) ⇒ <code>string</code>
Formats a nodehandler URI.

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>string</code> - The formatted URI.  

| Param | Type | Description |
| --- | --- | --- |
| module | <code>string</code> | A module name for scope, e.g. "twilio". |
| type | <code>string</code> | A simple URL safe type name, e.g. "echo". |

<a name="module_nodehandler-utils.._constructUri"></a>

### nodehandler-utils~\_constructUri()
This method construct uri only if necessary information is provided in the swagger.
Moreover it takes the fits scheme from the list of provided schemes.
This probably must be configurable during runtime in the future.

**Kind**: inner method of [<code>nodehandler-utils</code>](#module_nodehandler-utils)  
<a name="module_nodehandler-utils..generateFunctionName"></a>

### nodehandler-utils~generateFunctionName(swpath, method) ⇒ <code>string</code>
Method to create custom operationID-like operation id. Taken from connectors team
NOTE: duplicated from code from arrow-admin-api/src/util.js,

**Kind**: inner method of [<code>nodehandler-utils</code>](#module_nodehandler-utils)  
**Returns**: <code>string</code> - The custom operationID  

| Param | Type | Description |
| --- | --- | --- |
| swpath | <code>string</code> | The swagger path (eg. /thing) |
| method | <code>string</code> | The swagger method/verb (eg. "GET") |


## Building

```bash
npm run build
```

## Author

Axway <support@axway.com> https://axway.com

## Changes

#### 4.0.0
- #4919: Now exports spec and metadata
- #4918: Adds authorizations to the spec

#### 3.0.11
- #5111: Fixed bug where swagger documents with extensions in the same location as path methods failed to load correctly.

#### 3.0.10
- #5112: Previously, schemas generated from a swagger document with no "definitions" section was returned as `undefined`. Now, an empty array will be returned instead.

#### 3.0.3
- #4757: Changed SCM repository and associated internal cleanup.
- #4860: Previously, api-builder-plugin-fn-swagger would throw "Error: Invalid reference token" when attempting to handle URI encoded JSON schema references in Swagger files. Now, invalid reference errors are not thrown.

## License

This code is proprietary, closed source software licensed to you by Axway. All Rights Reserved. You may not modify Axway’s code without express written permission of Axway. You are licensed to use and distribute your services developed with the use of this software and dependencies, including distributing reasonable and appropriate portions of the Axway code and dependencies. Except as set forth above, this code MUST not be copied or otherwise redistributed without express written permission of Axway. This module is licensed as part of the Axway Platform and governed under the terms of the Axway license agreement (General Conditions) located here: [https://support.axway.com/en/auth/general-conditions](https://support.axway.com/en/auth/general-conditions); EXCEPT THAT IF YOU RECEIVED A FREE SUBSCRIPTION, LICENSE, OR SUPPORT SUBSCRIPTION FOR THIS CODE, NOTWITHSTANDING THE LANGUAGE OF THE GENERAL CONDITIONS, AXWAY HEREBY DISCLAIMS ALL SUPPORT AND MAINTENANCE OBLIGATIONS, AS WELL AS ALL EXPRESS AND IMPLIED WARRANTIES, INCLUDING BUT NOT LIMITED TO IMPLIED INFRINGEMENT WARRANTIES, WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, AND YOU ACCEPT THE PRODUCT AS-IS AND WITH ALL FAULTS, SOLELY AT YOUR OWN RISK. Your right to use this software is strictly limited to the term (if any) of the license or subscription originally granted to you.
